<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 *
 * @package    TheWorld
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower( $themename ) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );

}

/**
 * Defines an array of options that will be used to generate the settings page 
 * and be saved in the database.
 *
 * @since  1.0.0
 * @access public
 */
function optionsframework_options() {

	// Pull all tags into an array.
	$tags = array();
	$tags_obj = get_tags();
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_html( $tag->name );
	}

	// Pull all the categories into an array
	$categories = array();
	$categories_obj = get_categories();
	foreach ( $categories_obj as $category ) {
		$categories[$category->cat_ID] = esc_html( $category->cat_name );
	}

	// Background thumbnail path.
	$imgpath =  get_template_directory_uri() . '/assets/img/bg/';

	$options = array();

	$options[] = array(
		'name' => __( 'General', 'theworld' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Logo Uploader', 'theworld' ),
		'desc' => __( 'Upload your custom logo, it will automatically replace the Site Title', 'theworld' ),
		'id'   => 'theworld_logo',
		'type' => 'upload'
	);

	$options[] = array(
		'name' => __( 'Favicon Uploader', 'theworld' ),
		'desc' => __( 'Upload your custom favicon.', 'theworld' ),
		'id'   => 'theworld_favicon',
		'type' => 'upload'
	);

	$options[] = array(
		'name'  => __( 'FeedBurner URL', 'theworld' ),
		'desc'  => __( 'Enter your full FeedBurner URL. If you wish to use FeedBurner over the standard WordPress feed.', 'theworld' ),
		'id'    => 'theworld_feedburner_url',
		'placeholder' => 'http://feeds.feedburner.com/ThemeJunkie',
		'type'  => 'text'
	);

	$options[] = array(
		'name'    => __( 'Colors', 'theworld' ),
		'desc'    => __( 'Pick a skin/color you like.', 'theworld' ),
		'id'      => 'theworld_colors',
		'type'    => 'select',
		'std'     => 'green',
		'options' => array(
			'blue'        => __( 'Blue', 'theworld' ),
			'beige'       => __( 'Beige', 'theworld' ),
			'brown'       => __( 'Brown', 'theworld' ),
			'cyan'        => __( 'Cyan', 'theworld' ),
			'deep-blue'   => __( 'Deep Blue', 'theworld' ),
			'dirty-green' => __( 'Dirty Green', 'theworld' ),
			'green'       => __( 'Green', 'theworld' ),
			'red'         => __( 'Red', 'theworld' ),
		)
	);

	$options[] = array(
		'name' => __( 'Home Page', 'theworld' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Display Featured Posts', 'theworld' ),
		'desc' => __( 'Enable the Featured Posts area on home page.', 'theworld' ),
		'id'   => 'theworld_enable_featured',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name'    => __( 'Featured Posts Tag', 'theworld' ),
		'desc'    => __( 'Select a tag to be used as Featured Posts.', 'theworld' ),
		'id'      => 'theworld_featured_tag',
		'type'    => 'select',
		'options' => $tags
	);

	$options[] = array(
		'name' => __( 'Display Editor\'s Picks', 'theworld' ),
		'desc' => __( 'Enable the editor\'s picks area on home page.', 'theworld' ),
		'id'   => 'theworld_enable_editor_picks',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name'    => __( 'Editor\'s Picks Tag', 'theworld' ),
		'desc'    => __( 'Select a tag to be used as Editor\'s Picks Posts', 'theworld' ),
		'id'      => 'theworld_editor_picks_tag',
		'type'    => 'select',
		'options' => $tags
	);

	$options[] = array(
		'name' => __( 'Single Post', 'theworld' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Display author info ', 'theworld' ),
		'desc' => __( 'Enable the author biographical info.', 'theworld' ),
		'id'   => 'theworld_post_author',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Display share links', 'theworld' ),
		'desc' => __( 'Enable the share links.', 'theworld' ),
		'id'   => 'theworld_post_share',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Display related posts', 'theworld' ),
		'desc' => __( 'Enable the related posts.', 'theworld' ),
		'id'   => 'theworld_related_posts',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Before Content Advertisement', 'theworld' ),
		'desc' => __( 'Your ad will appear on single post before content.', 'theworld' ),
		'id'   => 'theworld_ad_single_before',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'After Content Advertisement', 'theworld' ),
		'desc' => __( 'Your ad will appear on single post after content.', 'theworld' ),
		'id'   => 'theworld_ad_single_after',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'Social Links', 'theworld' ),
		'type' => 'heading'
	);

	$options['theworld_enable_social'] = array(
		'name' => __( 'Enable ', 'theworld' ),
		'desc' => __( 'Enable social links', 'theworld' ),
		'id'   => 'theworld_enable_social',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options['theworld_fb'] = array(
		'name' => __( 'Facebook', 'theworld' ),
		'desc' => __( 'Facebook profile url', 'theworld' ),
		'id'   => 'theworld_fb',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['theworld_tw'] = array(
		'name' => __( 'Twitter', 'theworld' ),
		'desc' => __( 'Twitter profile url', 'theworld' ),
		'id'   => 'theworld_tw',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['theworld_gplus'] = array(
		'name' => __( 'Google Plus', 'theworld' ),
		'desc' => __( 'Google Plus profile url', 'theworld' ),
		'id'   => 'theworld_gplus',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['theworld_pinterest'] = array(
		'name' => __( 'Pinterest', 'theworld' ),
		'desc' => __( 'Pinterest profile url', 'theworld' ),
		'id'   => 'theworld_pinterest',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['theworld_linkedin'] = array(
		'name' => __( 'LinkedIn', 'theworld' ),
		'desc' => __( 'LinkedIn profile url', 'theworld' ),
		'id'   => 'theworld_linkedin',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['theworld_feed'] = array(
		'name' => __( 'RSS Feed', 'theworld' ),
		'desc' => __( 'RSS Feed url', 'theworld' ),
		'id'   => 'theworld_feed',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['theworld_newsletter'] = array(
		'name' => __( 'Newsletter', 'theworld' ),
		'desc' => __( 'Newsletter url', 'theworld' ),
		'id'   => 'theworld_newsletter',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Advertisement', 'theworld' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Header Advertisement', 'theworld' ),
		'desc' => __( 'Add your ad code to the text box. Recommended size 728x90', 'theworld' ),
		'id'   => 'theworld_header_ads',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'Custom Code', 'theworld' ),
		'type' => 'heading'
	);

	$options['theworld_script_head'] = array(
		'name' => __( 'Header code', 'theworld' ),
		'desc' => __( 'If you need to add custom scripts to your header (meta tag verification, google fonts url), you should enter them in the box. They will be added before &lt;/head&gt; tag', 'theworld' ),
		'id'   => 'theworld_script_head',
		'type' => 'textarea'
	);

	$options['theworld_script_footer'] = array(
		'name' => __( 'Footer code', 'theworld' ),
		'desc' => __( 'If you need to add custom scripts to your footer (like google analytic script), you should enter them in the box. They will be added before &lt;/body&gt; tag', 'theworld' ),
		'id'   => 'theworld_script_footer',
		'type' => 'textarea'
	);

	/* Return the theme settings data. */
	return $options;
}