<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 * 
 * @package    TheWorld
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function theworld_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'theworld_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'theworld_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so theworld_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so theworld_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in theworld_categorized_blog.
 *
 * @since 1.0.0
 */
function theworld_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'theworld_categories' );
}
add_action( 'edit_category', 'theworld_category_transient_flusher' );
add_action( 'save_post',     'theworld_category_transient_flusher' );

if ( ! function_exists( 'theworld_site_branding' ) ) :
/**
 * Site branding for the site.
 * 
 * Display site title by default, but user can change it with their custom logo.
 * They can upload it on Customizer page.
 * 
 * @since  1.0.0
 */
function theworld_site_branding() {

	$logo = of_get_option( 'theworld_logo' );

	// Check if logo available, then display it.
	if ( $logo ) :
		echo '<div id="logo" itemscope itemtype="http://schema.org/Brand">' . "\n";
			echo '<a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home">' . "\n";
				echo '<img itemprop="logo" src="' . esc_url( $logo ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" />' . "\n";
			echo '</a>' . "\n";
		echo '</div>' . "\n";

	// If not, then display the Site Title.
	else :
		echo '<div id="logo"><h1 class="site-title" ' . hybrid_get_attr( 'site-title' ) . '><a href="' . esc_url( get_home_url() ) . '" rel="home">' . esc_attr( get_bloginfo( 'name' ) ) . '</a></h1></div>';
	endif;

}
endif;

if ( ! function_exists( 'theworld_social_links' ) ) :
/**
 * Social links
 *
 * @since  1.0.0
 */
function theworld_social_links() {

	// Get option value.
	$enable     = of_get_option( 'theworld_enable_social', '1' );
	$facebook   = of_get_option( 'theworld_fb' );
	$twitter    = of_get_option( 'theworld_tw' );
	$gplus      = of_get_option( 'theworld_gplus' );
	$pinterest  = of_get_option( 'theworld_pinterest' );
	$linkedin   = of_get_option( 'theworld_linkedin' );
	$feed       = of_get_option( 'theworld_feed' );
	$newsletter = of_get_option( 'theworld_newsletter' );

	// Check if social links option enabled.
	if ( $enable ) {

		if ( $facebook ) {
			echo '<a class="tooltip" href="' . esc_url( $facebook ) . '" title="Facebook"><i class="fa fa-facebook"></i></a>';
		}
		if ( $twitter ) {
			echo '<a class="tooltip" href="' . esc_url( $twitter ) . '" title="Twitter"><i class="fa fa-twitter"></i></a>';
		}
		if ( $gplus ) {
			echo '<a class="tooltip" href="' . esc_url( $gplus ) . '" title="GooglePlus"><i class="fa fa-google-plus"></i></a>';
		}
		if ( $pinterest ) {
			echo '<a class="tooltip" href="' . esc_url( $pinterest ) . '" title="Pinterest"><i class="fa fa-pinterest"></i></a>';
		}
		if ( $linkedin ) {
			echo '<a class="tooltip" href="' . esc_url( $linkedin ) . '" title="LinkedIn"><i class="fa fa-linkedin"></i></a>';
		}
		if ( $feed ) {
			echo '<a class="tooltip" href="' . esc_url( $feed ) . '" title="RSS"><i class="fa fa-rss"></i></a>';
		}
		if ( $newsletter ) {
			echo '<a class="tooltip" href="' . esc_url( $newsletter ) . '" title="Newsletter"><i class="fa fa-envelope-o"></i></a>';
		}

	}

}
endif;

if ( ! function_exists( 'theworld_popular_posts_carousel' ) ) :
/**
 * Popular posts carousel
 *
 * @since  1.0.0
 */
function theworld_popular_posts_carousel() {

	// Get any existing copy of our transient data.
	if ( false === ( $popular = get_transient( 'theworld_popular_posts_cache' ) ) ) {
		// It wasn't there, so regenerate the data and save the transient.
		
		// Posts query arguments.
		$query = array(
			'post_type'      => 'post',
			'orderby'        => 'comment_count',
			'posts_per_page' => 10
		);

		// Allow dev to filter the query.
		$args = apply_filters( 'theworld_popular_posts_args', $query );

		// The post query
		$popular = new WP_Query( $args );

		// Store the transient.
		set_transient( 'theworld_popular_posts_cache', $popular );
	}

	if ( $popular->have_posts() ) : ?>

		<div id="related-content" class="clearfix" itemscope itemtype="http://schema.org/Blog">
			<div class="container">
				<h3 class="section-title"><?php _e( 'Popular Posts...', 'theworld' ); ?></h3>
				<div id="carousel-2" class="jcarousel">
					<ul>
						<?php while ( $popular->have_posts() ) : $popular->the_post(); ?>
							<li>
								<article id="post-<?php the_ID(); ?>" <?php post_class(); ?> <?php hybrid_attr( 'post' ); ?>>
									<?php if ( has_post_thumbnail() ) : ?>
										<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'theworld-carousel', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
									<?php endif; ?>
									<div class="entry-meta"><time class="entry-date" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( get_the_date() ); ?></time></div>
									<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
								</article>
							</li>
						<?php endwhile; ?>
					</ul>
				</div>

				<a href="#" class="jcarousel-control-prev"><i class="fa fa-chevron-left"></i></a>
				<a href="#" class="jcarousel-control-next"><i class="fa fa-chevron-right"></i></a>

			</div>
		</div>
	
	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

/**
 * Flush out the transients used in theworld_popular_posts_carousel.
 *
 * @since 1.0.0
 */
function theworld_popular_posts_flusher() {
	delete_transient( 'theworld_popular_posts_cache' );
}
add_action( 'save_post', 'theworld_popular_posts_flusher' );

if ( ! function_exists( 'theworld_related_posts' ) ) :
/**
 * Related posts carousel
 *
 * @since  1.0.0
 */
function theworld_related_posts() {
	global $post;

	// Bail if user don't want to display the author info via theme settings.
	if ( ! of_get_option( 'theworld_related_posts', '1' ) ) {
		return;
	}

	// Get the taxonomy terms of the current page for the specified taxonomy.
	$terms = wp_get_post_terms( $post->ID, 'category', array( 'fields' => 'ids' ) );

	// Bail if the term empty.
	if ( empty( $terms ) ) {
		return;
	}
	
	// Posts query arguments.
	$query = array(
		'post__not_in' => array( $post->ID ),
		'tax_query'    => array(
			array(
				'taxonomy' => 'category',
				'field'    => 'id',
				'terms'    => $terms,
				'operator' => 'IN'
			)
		),
		'posts_per_page' => 10,
		'post_type'      => 'post',
	);

	// Allow dev to filter the query.
	$args = apply_filters( 'theworld_related_posts_args', $query );

	// The post query
	$related = new WP_Query( $args );

	if ( $related->have_posts() ) : ?>

		<div id="related-content" class="clearfix" itemscope itemtype="http://schema.org/Blog">
			<div class="container">
				<h3 class="section-title"><?php _e( 'You might also like...', 'theworld' ); ?></h3>
				<div id="carousel-2" class="jcarousel">
					<ul>
						<?php while ( $related->have_posts() ) : $related->the_post(); ?>
							<li>
								<article id="post-<?php the_ID(); ?>" <?php post_class(); ?> <?php hybrid_attr( 'post' ); ?>>
									<?php if ( has_post_thumbnail() ) : ?>
										<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'theworld-carousel', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
									<?php endif; ?>
									<div class="entry-meta"><time class="entry-date" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( get_the_date() ); ?></time></div>
									<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
								</article>
							</li>
						<?php endwhile; ?>
					</ul>
				</div>

				<a href="#" class="jcarousel-control-prev"><i class="fa fa-chevron-left"></i></a>
				<a href="#" class="jcarousel-control-next"><i class="fa fa-chevron-right"></i></a>

			</div>
		</div>
	
	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

if ( ! function_exists( 'theworld_social_share' ) ) :
/**
 * Social share.
 *
 * @since  1.0.0
 */
function theworld_social_share() {
	global $post;

	// Bail if user don't want to display the share buttons via theme settings.
	if ( ! of_get_option( 'theworld_post_share', '1' ) ) {
		return;
	}
?>
	<span class="entry-share-icons">
		<span class="entry-share-icons">
			<a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" class="tooltip" title="Facebook"><i class="fa fa-facebook"></i></a>
			<a href="https://twitter.com/intent/tweet?text=<?php echo esc_attr( get_the_title( $post->ID ) ); ?>&url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" class="tooltip" title="Twitter"><i class="fa fa-twitter"></i></a>
			<a href="https://plus.google.com/share?url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" class="tooltip" title="GooglePlus"><i class="fa fa-google-plus"></i></a>
			<a href="https://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>&media=<?php echo wp_get_attachment_url( get_post_thumbnail_id( $post->ID ) ); ?>&description=<?php echo get_the_excerpt(); ?>" class="tooltip" title="Pinterest"><i class="fa fa-pinterest"></i></a>
			<a href="https://www.linkedin.com/shareArticle?mini=true&url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>&title=<?php echo esc_attr( get_the_title( $post->ID ) ); ?>&summary=<?php echo get_the_excerpt(); ?>&source=<?php echo esc_attr( get_bloginfo( 'name' ) ) ?>" class="tooltip" title="LinkedIn"><i class="fa fa-linkedin"></i></a>
		</span>
	</span>
<?php
}
endif;

if ( ! function_exists( 'theworld_post_author' ) ) :
/**
 * Author post informations.
 *
 * @since  1.0.0
 */
function theworld_post_author() {

	// Bail if not on the single post.
	if ( ! is_single() ) {
		return;
	}

	// Bail if user hasn't fill the Biographical Info field.
	if ( ! get_the_author_meta( 'description' ) ) {
		return;
	}

	// Bail if user don't want to display the author info via theme settings.
	if ( ! of_get_option( 'theworld_post_author', '1' ) ) {
		return;
	}
?>

	<section class="author-box clearfix" <?php hybrid_attr( 'entry-author' ) ?>>
		<?php echo get_avatar( is_email( get_the_author_meta( 'user_email' ) ), apply_filters( 'theworld_author_bio_avatar_size', 64 ), '', strip_tags( get_the_author() ) ); ?>
		<h3 class="author-title">
			<a class="author-name url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author" itemprop="url"><span itemprop="name"><?php echo strip_tags( get_the_author() ); ?></span></a>
		</h3>
		<p itemprop="description"><?php echo stripslashes( get_the_author_meta( 'description' ) ); ?></p>
	</section><!-- .author-box -->

<?php
}
endif;

if ( ! function_exists( 'theworld_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since  1.0.0
 */
function theworld_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<p <?php hybrid_attr( 'comment-content' ); ?>><?php _e( 'Pingback:', 'theworld' ); ?> <span <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php comment_author_link(); ?></span></span> <?php edit_comment_link( __( '(Edit)', 'theworld' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="comment">

			<?php echo get_avatar( $comment, 60 ); ?>
			
			<div class="comment-des">

				<div class="arrow-comment"></div>

				<div class="comment-by">
					<p class="author" <?php hybrid_attr( 'comment-author' ); ?>><strong><span itemprop="name"><?php echo get_comment_author_link(); ?></span></strong></p>
					<?php
						printf( '<p class="date"><a href="%1$s" ' . hybrid_get_attr( 'comment-permalink' ) . '><time datetime="%2$s" ' . hybrid_get_attr( 'comment-published' ) . '>%3$s</time></a> - %4$s</p>',
							esc_url( get_comment_link( $comment->comment_ID ) ),
							get_comment_time( 'c' ),
							/* translators: 1: date, 2: time */
							sprintf( __( '%1$s at %2$s', 'theworld' ), get_comment_date(), get_comment_time() ),
							sprintf( __( '%1$sEdit%2$s', 'theworld' ), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__( 'Edit Comment', 'theworld' ) . '">', '</a>' )
						);
					?>
					<span class="reply">
						<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'theworld' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
					</span><!-- .reply -->
				</div><!-- .comment-by -->

				<section class="comment-content comment" <?php hybrid_attr( 'comment-content' ); ?>>
					<?php if ( '0' == $comment->comment_approved ) : ?>
						<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'theworld' ); ?></p>
					<?php endif; ?>
					<?php comment_text(); ?>
				</section><!-- .comment-content -->

			</div><!-- .comment-des -->

		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

if ( ! function_exists( 'theworld_featured_posts' ) ) :
/**
 * Featured posts carousel
 *
 * @since  1.0.0
 */
function theworld_featured_posts() {

	$enable = of_get_option( 'theworld_enable_featured', '1' ); // Enable disable featured posts.
	$tag    = of_get_option( 'theworld_featured_tag' );         // Get the user selected tag for the featured posts.

	// Bail if disable by user.
	if ( ! $enable ) {
		return;
	}

	// Get any existing copy of our transient data.
	if ( false === ( $featured = get_transient( 'theworld_featured_posts_cache' ) ) ) {
		// It wasn't there, so regenerate the data and save the transient.
		
		// Posts query arguments.
		$query = array(
			'post_type'      => 'post',
			'posts_per_page' => 3,
		);

		// Add the tag selected by user to the query.
		if ( ! empty( $tag ) ) {
			$query['tag_id'] = $tag;
		}

		// Allow dev to filter the query.
		$args = apply_filters( 'theworld_featured_posts_args', $query );

		// The post query
		$featured = new WP_Query( $args );

		// Store the transient.
		set_transient( 'theworld_featured_posts_cache', $featured );
	}

	if ( $featured->have_posts() ) : ?>

		<div id="featured-content" class="clearfix" itemscope itemtype="http://schema.org/Blog">
			<div class="container">

				<div id="carousel-0" class="jcarousel">
					<ul>
						<?php while ( $featured->have_posts() ) : $featured->the_post(); ?>
							<li>
								<article id="post-<?php the_ID(); ?>" <?php post_class(); ?> <?php hybrid_attr( 'post' ); ?>>
									<?php if ( has_post_thumbnail() ) : ?>
										<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'theworld-featured', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
									<?php endif; ?>
									<div class="entry-meta">
										<?php
											/* translators: used between list items, there is a space after the comma */
											$categories_list = get_the_category_list( __( ', ', 'theworld' ) );
											if ( $categories_list && theworld_categorized_blog() ) :
										?>
											<span class="entry-category" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
												<?php echo $categories_list; ?>
											</span>
										<?php endif; // End if categories ?>
										<time class="entry-date" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( get_the_date() ); ?></time>
									</div>
									<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
									<div class="byline">
										<span class="entry-view"><?php echo do_shortcode( '[entry-views after="' . __( ' Views', 'theworld' ) . '"]' ); ?></span>
										<?php if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) : ?>
											<span class="entry-comment"><?php comments_popup_link( __( '0', 'theworld' ), __( '1', 'theworld' ), __( '%', 'theworld' ) ); ?></span>
										<?php endif; ?>
										<span class="entry-author author vcard" <?php hybrid_attr( 'entry-author' ) ?>><?php printf( __( 'by <a class="url fn n" href="%1$s" itemprop="url"><span itemprop="name">%2$s</span></a>', 'theworld' ), esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ), esc_html( get_the_author() ) ); ?></span>
									</div>

									<div class="entry-summary" <?php hybrid_attr( 'entry-summary' ); ?>>
										<?php the_excerpt(); ?>
									</div><!-- .entry-summary -->

									<?php theworld_social_share(); // Get the social share. ?>
								</article>
							</li>
						<?php endwhile; ?>
					</ul>
				</div>

				<p class="jcarousel-pagination"></p>

				<a href="#" class="jcarousel-control-prev"><i class="fa fa-chevron-left"></i></a>
				<a href="#" class="jcarousel-control-next"><i class="fa fa-chevron-right"></i></a>

			</div>
		</div>
	
	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

/**
 * Flush out the transients used in theworld_featured_posts.
 *
 * @since 1.0.0
 */
function theworld_featured_posts_flusher() {
	delete_transient( 'theworld_featured_posts_cache' );
}
add_action( 'save_post', 'theworld_featured_posts_flusher' );
add_action( 'optionsframework_after_validate', 'theworld_featured_posts_flusher' );

if ( ! function_exists( 'theworld_latest_posts_home' ) ) :
/**
 * Latest 6 posts.
 *
 * @since  1.0.0
 */
function theworld_latest_posts_home() {

	// Get any existing copy of our transient data.
	if ( false === ( $latest = get_transient( 'theworld_latest_6_posts_cache' ) ) ) {
		// It wasn't there, so regenerate the data and save the transient.
		
		// Posts query arguments.
		$query = array(
			'post_type'      => 'post',
			'posts_per_page' => 6,
		);

		// Allow dev to filter the query.
		$args = apply_filters( 'theworld_latest_6_posts_args', $query );

		// The post query
		$latest = new WP_Query( $args );

		// Store the transient.
		set_transient( 'theworld_latest_6_posts_cache', $latest );
	}

	if ( $latest->have_posts() ) : ?>

		<div id="recent-content" class="container clearfix" itemscope itemtype="http://schema.org/Blog">

			<h3 class="section-title">
				<?php _e( 'Latest News', 'theworld' ); ?>
				<?php if ( get_option( 'show_on_front' ) == 'page' ) echo '<span class="see-all"><a href="' . get_permalink( get_option('page_for_posts' ) ) . '">' . __( 'See All', 'theworld' ) . ' <i class="fa fa-angle-right"></i></a></span>'; ?>
			</h3>	
			
			<?php $i = 0; ?>
			<?php while ( $latest->have_posts() ) : $latest->the_post(); ?>

			<?php
				$i++;
				$class = '';
				if ( 0 === ( $i % 3 ) ) {
					$class = 'last-post';
				}
			?>

				<article id="post-<?php the_ID(); ?>" <?php post_class( $class ); ?> <?php hybrid_attr( 'post' ); ?>>
					<?php if ( has_post_thumbnail() ) : ?>
						<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'theworld-featured', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
					<?php endif; ?>
					<div class="entry-meta">
						<?php
							/* translators: used between list items, there is a space after the comma */
							$categories_list = get_the_category_list( __( ', ', 'theworld' ) );
							if ( $categories_list && theworld_categorized_blog() ) :
						?>
							<span class="entry-category" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
								<?php echo $categories_list; ?>
							</span>
						<?php endif; // End if categories ?>
						<time class="entry-date" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( get_the_date() ); ?></time>
					</div>
					<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
					<div class="byline">
						<span class="entry-view"><?php echo do_shortcode( '[entry-views after="' . __( ' Views', 'theworld' ) . '"]' ); ?></span>
						<?php if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) : ?>
							<span class="entry-comment"><?php comments_popup_link( __( '0', 'theworld' ), __( '1', 'theworld' ), __( '%', 'theworld' ) ); ?></span>
						<?php endif; ?>
						<span class="entry-author author vcard" <?php hybrid_attr( 'entry-author' ) ?>><?php printf( __( 'by <a class="url fn n" href="%1$s" itemprop="url"><span itemprop="name">%2$s</span></a>', 'theworld' ), esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ), esc_html( get_the_author() ) ); ?></span>
					</div>

					<div class="entry-summary" <?php hybrid_attr( 'entry-summary' ); ?>>
						<?php the_excerpt(); ?>
					</div><!-- .entry-summary -->

					<?php theworld_social_share(); // Get the social share. ?>
				</article>

				<?php if ( 0 === ( $i % 3 ) ) echo '<div class="clearfix"></div>'; ?>
			<?php endwhile; ?>

		</div>
	
	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

/**
 * Flush out the transients used in theworld_latest_posts_home.
 *
 * @since 1.0.0
 */
function theworld_latest_6_posts_flusher() {
	delete_transient( 'theworld_latest_6_posts_cache' );
}
add_action( 'save_post', 'theworld_latest_6_posts_flusher' );

if ( ! function_exists( 'theworld_editors_picks_posts' ) ) :
/**
 * Editor's Picks posts carousel
 *
 * @since  1.0.0
 */
function theworld_editors_picks_posts() {

	$enable = of_get_option( 'theworld_enable_editor_picks', '1' ); // Enable disable featured posts.
	$tag    = of_get_option( 'theworld_editor_picks_tag' );         // Get the user selected tag for the featured posts.

	// Bail if disable by user.
	if ( ! $enable ) {
		return;
	}

	// Get any existing copy of our transient data.
	if ( false === ( $editors = get_transient( 'theworld_editors_posts_cache' ) ) ) {
		// It wasn't there, so regenerate the data and save the transient.
		
		// Posts query arguments.
		$query = array(
			'post_type'      => 'post',
			'posts_per_page' => 10,
		);

		// Add the tag selected by user to the query.
		if ( ! empty( $tag ) ) {
			$query['tag_id'] = $tag;
		}

		// Allow dev to filter the query.
		$args = apply_filters( 'theworld_editors_posts_args', $query );

		// The post query
		$editors = new WP_Query( $args );

		// Store the transient.
		set_transient( 'theworld_editors_posts_cache', $editors );
	}

	if ( $editors->have_posts() ) : ?>

		<div id="carousel-1" class="carousel-loop clearfix" itemscope itemtype="http://schema.org/Blog">
			<div class="container">

				<h3 class="section-title"><?php _e( 'Editor\'s Picks', 'theworld' ); ?></h3>

				<div class="jcarousel">
					<ul>
						<?php while ( $editors->have_posts() ) : $editors->the_post(); ?>
							<li>
								<article id="post-<?php the_ID(); ?>" <?php post_class(); ?> <?php hybrid_attr( 'post' ); ?>>
									<?php if ( has_post_thumbnail() ) : ?>
										<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'theworld-editors', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
									<?php endif; ?>
									<div class="entry-meta">
										<?php
											/* translators: used between list items, there is a space after the comma */
											$categories_list = get_the_category_list( __( ', ', 'theworld' ) );
											if ( $categories_list && theworld_categorized_blog() ) :
										?>
											<span class="entry-category" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
												<?php echo $categories_list; ?>
											</span>
										<?php endif; // End if categories ?>
										<time class="entry-date" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( get_the_date() ); ?></time>
									</div>
									<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
								</article>
							</li>
						<?php endwhile; ?>
					</ul>
				</div>

				<a href="#" class="jcarousel-control-prev"><i class="fa fa-chevron-left"></i></a>
				<a href="#" class="jcarousel-control-next"><i class="fa fa-chevron-right"></i></a>

			</div>
		</div>
	
	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

/**
 * Flush out the transients used in theworld_editors_picks_posts.
 *
 * @since 1.0.0
 */
function theworld_editors_posts_flusher() {
	delete_transient( 'theworld_editors_posts_cache' );
}
add_action( 'save_post', 'theworld_editors_posts_flusher' );
add_action( 'optionsframework_after_validate', 'theworld_editors_posts_flusher' );

if ( ! function_exists( 'theworld_another_latest_posts_home' ) ) :
/**
 * More posts.
 *
 * @since  1.0.0
 */
function theworld_another_latest_posts_home() {

	// Get any existing copy of our transient data.
	if ( false === ( $another = get_transient( 'theworld_latest_8_posts_cache' ) ) ) {
		// It wasn't there, so regenerate the data and save the transient.
		
		// Posts query arguments.
		$query = array(
			'post_type'      => 'post',
			'posts_per_page' => 8,
			'offset'         => 6,
		);

		// Allow dev to filter the query.
		$args = apply_filters( 'theworld_latest_8_posts_args', $query );

		// The post query
		$another = new WP_Query( $args );

		// Store the transient.
		set_transient( 'theworld_latest_8_posts_cache', $another );
	}

	if ( $another->have_posts() ) : ?>

		<h3 class="section-title">
			<?php _e( 'More News', 'theworld' ); ?>
			<?php if ( get_option( 'show_on_front' ) == 'page' ) echo '<span class="see-all"><a href="' . get_permalink( get_option('page_for_posts' ) ) . '">' . __( 'See All', 'theworld' ) . ' <i class="fa fa-angle-right"></i></a></span>'; ?>
		</h3>
		
		<ul itemscope itemtype="http://schema.org/Blog">

			<?php while ( $another->have_posts() ) : $another->the_post(); ?>
				
				<li class="clearfix">
					<article id="post-<?php the_ID(); ?>" <?php post_class(); ?> <?php hybrid_attr( 'post' ); ?>>
						<?php if ( has_post_thumbnail() ) : ?>
							<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'theworld-editors', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
						<?php endif; ?>
						<div class="entry-meta">
							<?php
								/* translators: used between list items, there is a space after the comma */
								$categories_list = get_the_category_list( __( ', ', 'theworld' ) );
								if ( $categories_list && theworld_categorized_blog() ) :
							?>
								<span class="entry-category" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
									<?php echo $categories_list; ?>
								</span>
							<?php endif; // End if categories ?>
							<time class="entry-date" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( get_the_date() ); ?></time>
						</div>
						<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
						<div class="byline">
							<span class="entry-view"><?php echo do_shortcode( '[entry-views after="' . __( ' Views', 'theworld' ) . '"]' ); ?></span>
							<?php if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) : ?>
								<span class="entry-comment"><?php comments_popup_link( __( '0', 'theworld' ), __( '1', 'theworld' ), __( '%', 'theworld' ) ); ?></span>
							<?php endif; ?>
							<span class="entry-author author vcard" <?php hybrid_attr( 'entry-author' ) ?>><?php printf( __( 'by <a class="url fn n" href="%1$s" itemprop="url"><span itemprop="name">%2$s</span></a>', 'theworld' ), esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ), esc_html( get_the_author() ) ); ?></span>
						</div>
						<div class="entry-summary" <?php hybrid_attr( 'entry-summary' ); ?>>
							<p><?php echo wp_trim_words( get_the_excerpt(), 8 ); ?></p>
						</div><!-- .entry-summary -->

						<?php theworld_social_share(); // Get the social share. ?>
					</article>
				</li>

			<?php endwhile; ?>

		</ul>
		
		<?php if ( get_option( 'show_on_front' ) == 'page' ) : ?>
			<div class="more-content-link">
				<a href="<?php echo get_permalink( get_option('page_for_posts' ) ); ?>"><?php _e( 'Browse All News', 'theworld' ); ?></a>
			</div>
		<?php endif; ?>
	
	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

/**
 * Flush out the transients used in theworld_another_latest_posts_home.
 *
 * @since 1.0.0
 */
function theworld_latest_8_posts_flusher() {
	delete_transient( 'theworld_latest_8_posts_cache' );
}
add_action( 'save_post', 'theworld_latest_8_posts_flusher' );